# personalcolorchecker

By giving your photo as data, it will tell you your personal color based on your eye color and skin color.

# how to install personalcolorchecker
$ pip install personalcolorchecker

# how to personalcolor
Download "haarcascade_frontalface_default.xml"


$ import personalcolorchecker

$ import cv2


$ img = cv2.imread("image.jpg")

$ personalcolorchecker.personal_color(img)


<img src='https://github.com/harunearakage/personalcolor/blob/main/result.png' width=640 hight=480>
